import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * CloudFormation template for Subscription Peering.
 *
 * @schema CfnSubscriptionPeeringProps
 */
export interface CfnSubscriptionPeeringProps {
    /**
     * [Required]. The Base URL where the API calls are sent.
     *
     * @schema CfnSubscriptionPeeringProps#BaseUrl
     */
    readonly baseUrl?: string;
    /**
     * [Required]. The ID of the Pro Subscription that will make a peering connection. Example: 163199
     *
     * @schema CfnSubscriptionPeeringProps#SubscriptionID
     */
    readonly subscriptionId: string;
    /**
     * [Optional]. Cloud provider. Example: AWS. Default: 'AWS'
     *
     * @schema CfnSubscriptionPeeringProps#Provider
     */
    readonly provider?: string;
    /**
     * [Required for AWS]. Deployment region as defined by cloud provider. Example: us-east-1
     *
     * @schema CfnSubscriptionPeeringProps#Region
     */
    readonly region?: string;
    /**
     * [Required for AWS]. AWS Account uid. Example: 178919255286
     *
     * @schema CfnSubscriptionPeeringProps#AwsAccountId
     */
    readonly awsAccountId?: string;
    /**
     * [Required for AWS]. VPC uid. Example: vpc-00e1a8cdca658ce8c
     *
     * @schema CfnSubscriptionPeeringProps#VpcId
     */
    readonly vpcId?: string;
    /**
     * [Optional]. VPC CIDR. Example:  '10.10.10.0/24'
     *
     * @schema CfnSubscriptionPeeringProps#VpcCidr
     */
    readonly vpcCidr?: string;
    /**
     * [Optional]. List of VPC CIDRs. Example: '[10.10.10.0/24,10.10.20.0/24]'
     *
     * @schema CfnSubscriptionPeeringProps#VpcCidrs
     */
    readonly vpcCidrs?: string[];
    /**
     * [Required for GCP]. VPC project uid.
     *
     * @schema CfnSubscriptionPeeringProps#VpcProjectUid
     */
    readonly vpcProjectUid?: string;
    /**
     * [Required for GCP]. VPC network name.
     *
     * @schema CfnSubscriptionPeeringProps#VpcNetworkName
     */
    readonly vpcNetworkName?: string;
}
/**
 * Converts an object of type 'CfnSubscriptionPeeringProps' to JSON representation.
 */
export declare function toJson_CfnSubscriptionPeeringProps(obj: CfnSubscriptionPeeringProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Redis::CloudFormation::SubscriptionPeering`
 *
 * @cloudformationResource Redis::CloudFormation::SubscriptionPeering
 * @stability external
 * @link http://unknown-url
 */
export declare class CfnSubscriptionPeering extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Redis::CloudFormation::SubscriptionPeering";
    /**
     * Resource props.
     */
    readonly props: CfnSubscriptionPeeringProps;
    /**
     * Attribute `Redis::CloudFormation::SubscriptionPeering.PeeringID`
     * @link http://unknown-url
     */
    readonly attrPeeringID: string;
    /**
     * Create a new `Redis::CloudFormation::SubscriptionPeering`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnSubscriptionPeeringProps);
}
